-------------------------------------------------------------------
-------------------------------------------------------------------
-- Rakus Training Spawns (RTS)									 --
-- a highly configurable script for dynamic aircraft spawns		 --
-- 																 --
-- Author: Raku													 --
-- using Grimes and Speeds Mission Scripting Tools MiST			 --
--																 --
-- carefully read the comments on the configuration variables!	 --
-- they may answer some question you may have					 --
-- oh... the usage explanation down below might be useful aswell --
-- ;-)															 --
-------------------------------------------------------------------
-------------------------------------------------------------------
do -- don't touch this do! just leave it here. it won't bite you, i promise.

-- the general script usage is intended as follows
-- this script exposes a function:
--
-- void RTS.spawnAircraft(table difficulty, number coal, table spawnZones, string flyToZone)
--
-- difficulty - can be RTS.Easy, RTS.Medium, RTS.Heavy or RTS.Hard
-- coal - coalition to spawn the aircraft under. either coalition.side.BLUE or coalition.side.RED
-- spawnZones - a table of the names of triggerzones the aircraft can spawn in. actual zone will be taken from the table at random.
-- flyToZone - name of a triggerzone the aircraft will get a waypoint in.
--
-- no parameter is optional!
--
-- the triggerzones in spawnZones and the triggerzone flyToZone have to be placed in the mission editor!
--
-- examples:
--
-- RTS.spawnAircraft(RTS.Easy, coalition.side.RED, { 'EasySpawnZone' }, 'EasyTargetZone')
-- --> this spawns an easy aircraft from the RED coalition in a random point inside the trigger zone 'EasySpawnZone'
-- --> and gives the aircraft a waypoint at a random point inside the trigger zone named 'EasyTargetZone'
-- --> the spawned aircraft will fly a race track pattern between the spawn point and waypoint
--
-- RTS.SpawnAircraft(RTS.Hard, coalition.side.BLUE, { 'Hard1', 'Hard2', 'Hard3' }, 'HardTargetZone')
-- --> this spawns an hard aircraft from the BLUE coalition in a random point in one of the trigger zones 'Hard1', 'Hard2', 'Hard3'
-- --> the actual spawning zone will be chosen random!
-- --> the aircraft will get a waypoint to fly to inside the trigger zone named 'HardTargetZone'
-- --> the spawned aircraft will fly a race track pattern between the spawn point and waypoint
--
-- so generally you want at least two trigger zones on your map: one for a spawn zone and one for "fly to" zone
-- then it's up to you how you let the aircraft spawn (by calling that function i mentioned above)
-- maybe when the player reaches a waypoint?
-- maybe with a radio call?
-- all up to you - you just have to call RTS.spawnAircraft(...)
-- :-)

-- below comes everything you can configure
-- this script isn't foolproof (yet?), so please stick to the data types of the variables

-- the prefix each spawned group will get.
-- if this prefix is already in use by you, then choose another unique one
RTSConf_GroupPrefix = 'RTS-'

-- difficulty configuration:
-- there are four difficulties (for now): easy, medium, hard and heavy

-- easy: aircraft are completely unarmed, have no countermeasures and won't attack you. most likely they won't maneuver either.
-- medium: aircraft are armed with gun only (and countermeasures) and will attack
-- hard: aircraft are fully armed and will attack
-- heavy: heavy bombers or transporters
--
-- for each diffulty you can set the available aircraft, flightsize and spawning altitude
-- RTSConf_FixedWing_XXX are the available aircraft. this has to be a table, so don't change the format
-- if you only want one aircraft, then make it like this: { 'Su-27' }
-- the aircraft type is taken from the aircraft configuration further down!
-- the flightsize is the number of aircraft spawned simultaneously for this difficulty
-- altitude is the altitude the aircraft will spawn at - beware: METERS! - given as a range.
-- { 2000, 3000 } means the aircraft will spawn at a height between 2km and 3km
-- no fixed altitude for now and i'm not quite sure what { 2000, 2000 } will do to the script
-- maybe use { 2000, 2001 } for a fixed altitude... one meter won't hurt anyone (except you fall down a meter, this can actually hurt)
-- altitude type can either be 'RADIO' or 'BARO' - take this into account when setting up your trigger zones
-- a barometric height of 1km in the mountains of the caucasus can be quite ... challenging ;-)
RTSConf_FixedWing_Easy = { 'L-39C', 'Su-25', 'Su-25T', 'Su-25TM', 'Hawk' }
RTSConf_FixedWing_Easy_FlightSize = 1 -- default: 4
RTSConf_FixedWing_Easy_Altitude = { 2000,3000 } -- meter, default: { 2000,3000 }
RTSConf_FixedWing_Easy_AltType = 'RADIO' -- default: 'RADIO'

RTSConf_FixedWing_Medium = { 'L-39ZA', 'M-2000C', 'Mirage 2000-5', 'F-4E', 'MiG-21Bis' }
RTSConf_FixedWing_Medium_FlightSize = 1 -- default: 2
RTSConf_FixedWing_Medium_Altitude = { 2000,5000 } -- meter, default: { 2000,5000 }
RTSConf_FixedWing_Medium_AltType = 'RADIO' -- default: 'RADIO'

RTSConf_FixedWing_Hard = { 'F/A-18C', 'F-15C', 'Su-27', 'Su-33', 'MiG-29S' }
RTSConf_FixedWing_Hard_FlightSize = 1 -- default: 2
RTSConf_FixedWing_Hard_Altitude = { 5000,7000 } -- meter, default: { 5000,7000 }
RTSConf_FixedWing_Hard_AltType = 'RADIO' -- default: 'RADIO'

RTSConf_FixedWing_Heavy = { 'Tu-160', 'Tu-142' }
-- heavy has a default flight size of 1!
RTSConf_FixedWing_Heavy_Altitude = { 7000,12000 } -- meter, default: { 7000,12000 }
RTSConf_FixedWing_Heavy_AltType = 'RADIO' -- default: 'RADIO'

-- here comes the group configuration
-- RTSConf_OneGroupPerDifficulty can either be true or false
-- if it is true, then there can only be one group with one difficulty active at the same time
-- so only one group for easy, medium, hard, ...
-- if this is false, then there can be multiple groups active at the same time - as many as you want
-- the timeout defines the timeout in seconds after which groups will be deleted if they are still alive
RTSConf_OneGroupPerDifficulty = true -- default: true
RTSConf_GroupTimeout = 10*60 -- seconds, default: 10*60 ( = 10 minutes)

-- these variables define what messages will be displayed
-- a message will be always displayed to ALL players in case this is run in multiplayer!
-- the message text can be configured below
-- except for GroupActive it should be clear when the messages are displayed
--
-- GroupActive will be displayed if RTSConf_OneGroupPerDifficulty is true
-- and you call RTS.spawnAircraft a second time for a difficulty while a group is still in the air
RTSConf_MessageGroupSpawned = true -- default: true
RTSConf_MessageGroupDead = true -- default: true
RTSConf_MessageGroupTimeout = true -- default: true
RTSConf_MessageGroupActive = false -- default: false

-- here are strings used for the messages - feel free to translate them to your language
RTSConf_StringEasy = "Easy" -- default: "Easy"
RTSConf_StringMedium = "Medium" -- default: "Medium"
RTSConf_StringHard = "Hard" -- default: "Hard"
RTSConf_StringHeavy = "Heavy" -- default: "Heavy"
-- in the RTSConf_StringGroupSpawned/Dead/Remove variables you can use substitutions (NOT in RTSConf_StringGroupActive):
-- $Difficulty will be replaced with the difficulty string (RTSConf_StringEasy, RTSConf_StringMedium, ...)
-- $Count will be replaced with the group counter - this is: the count of the groups already spawned with the certain difficulty
-- so if you're spawning the third easy group, the RTSConf_StringGroupSpawned message with the replacements will read:
-- 			Easy group 3 spawned!
RTSConf_StringGroupSpawned = "$Difficulty group $Count spawned!" -- default: "$Difficulty group $Count spawned!"
RTSConf_StringGroupDead = "$Difficulty group $Count down!" -- default: "$Difficulty group $Count down!"
RTSConf_StringGroupRemoved = "$Difficulty group $Count removed for idling too long!" -- default: "$Difficulty group $Count removed for idling too long!"
RTSConf_StringGroupActive = "Another group is still active!" -- default: "Another group is still active!"

-- aircraft configuration
-- now here's the fun part!
--
-- there are 7 variables here: RTBombers, RTFighters, RTTransport, RTCivilian, RTHelicoptersAttack, RTHelicoptersTransport and RTHelicoptersCivilian
--
-- each category-variable (RTBombers, RTHelicopters, ...) holds all available aircraft-types
-- at least all types i could find ;-)
--
-- each aircraft-type resp. aircraft-configuration consists of the following:
-- type - NEVER CHANGE THIS (if you do: don't blame me for this specific type not spawning)
-- active - not in use at the moment, has no effect
-- payload - the payload. format is just like in the mission files. see below how to get this.
-- coalition - coalition.side.BLUE, coalition.side.RED, coalition.side.NEUTRAL - not in use at the moment, has no effect
-- countries - a list of all countries the aircraft is available for
-- liveries - a list of liveries available to the aircraft for a certain country (see below)
--
-- at the moment the script will spawn the aircraft under the flag and livery of a random country
-- it won't take into account the coalition
--
-- the liveries are set for a certain country
-- for example if USA is country [1], then all liveries under [1] will only be used
-- if the script spawns this aircraft under the flag of the USA
--
-- how to get your own payload:
-- 1. load up the mission editor
-- 2. place aircraft with the loadout you want
-- 3. save mission (and exit DCS if you want to)
-- 4. navigate to C:\Users\<your username\Saved Games\DCS\Missions
-- 5. open <your mission>.miz with a zip-program of your choice (7zip, WinRAR, ...)
-- 6. extract and open or directly open the file named mission inside the archive
-- 7. scroll down and search your aircraft
-- 8. copy the block from ["payload"] to }, -- end of ["payload"] into the configuration here
--
-- searching for a certain aircraft type in here?
-- push Ctrl+F
-- if you're searching for aircraft types, search for: RTBombers, RTFighters, RTTransport, RTCivilian, RTHelicoptersAttack, RTHelicoptersTransport or RTHelicoptersCivilian
-- if you're searching for a specific aircraft: search its name like it's displayed in the mission-editor, for example: A-10C, Su-27, Su-24MR, Tu-95MS
RTBombers = {
	[1] = {
		["type"] = "B-52H",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
				[1] =
				{
					["CLSID"] = "{696CFFC4-0BDE-42A8-BE4B-0BE3D9DD723C}",
				}, -- end of [1]
				[3] =
				{
					["CLSID"] = "{696CFFC4-0BDE-42A8-BE4B-0BE3D9DD723C}",
				}, -- end of [3]
			}, -- end of ["pylons"]
			["fuel"] = "141135",
			["flare"] = 192,
			["chaff"] = 1125,
			["gun"] = 100,
		}, -- end of ["payload"]		
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "usaf standard" }, -- liveries for ["countries"][1]
		}		
	}, -- end of [1]
	[2] = {
		["type"] = "B-1B",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "MK_82*28",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "MK_82*28",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "MK_82*28",
				}, -- end of [3]
			}, -- end of ["pylons"]
			["fuel"] = "88450",
			["flare"] = 30,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]		
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "usaf standard" }, -- liveries for ["countries"][1]
		}		
	}, -- end of [2]
	[3] = {
		["type"] = "F-117A",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{51F9AAE5-964F-4D21-83FB-502E3BFE5F8A}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{51F9AAE5-964F-4D21-83FB-502E3BFE5F8A}",
				}, -- end of [2]
			}, -- end of ["pylons"]
			["fuel"] = "3840",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]		
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "usaf standard" }, -- liveries for ["countries"][1]
		}		
	}, -- end of [3]
	[4] = {
		["type"] = "Tu-160",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{0290F5DE-014A-4BB1-9843-D717749B1DED}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{0290F5DE-014A-4BB1-9843-D717749B1DED}",
				}, -- end of [2]
			}, -- end of ["pylons"]
			["fuel"] = "157000",
			["flare"] = 72,
			["chaff"] = 72,
			["gun"] = 100,
		}, -- end of ["payload"]	
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
		}		
	}, -- end of [4]
	[5] = {
		["type"] = "Tu-22M3",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{12429ECF-03F0-4DF6-BCBD-5D38B6343DE1}",
				}, -- end of [1]
				[5] = 
				{
					["CLSID"] = "{12429ECF-03F0-4DF6-BCBD-5D38B6343DE1}",
				}, -- end of [5]
			}, -- end of ["pylons"]
			["fuel"] = "50000",
			["flare"] = 48,
			["chaff"] = 48,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}		
	}, -- end of [5]
	[6] = {
		["type"] = "Tu-95MS",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{0290F5DE-014A-4BB1-9843-D717749B1DED}",
				}, -- end of [1]
			}, -- end of ["pylons"]
			["fuel"] = "87000",
			["flare"] = 48,
			["chaff"] = 48,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}		
	}, -- end of [6]
	[7] = {
		["type"] = "Tu-142",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{C42EE4C3-355C-4B83-8B22-B39430B8F4AE}",
				}, -- end of [1]
			}, -- end of ["pylons"]
			["fuel"] = "87000",
			["flare"] = 48,
			["chaff"] = 48,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
		}		
	}, -- end of [7]
} -- end of RTBombers
RTHelicoptersAttack = {
	[1] = {
		["type"] = "UH-1H",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
				[1] =
				{
					["CLSID"] = "M134_L",
				}, -- end of [1]
				[2] =
				{
					["CLSID"] = "XM158_MK5",
				}, -- end of [2]
				[3] =
				{
					["CLSID"] = "XM158_MK5",
				}, -- end of [3]
				[4] =
				{
					["CLSID"] = "M134_R",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "631",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.AUSTRALIA,
			[3] = country.id.CANADA,
			[4] = country.id.FRANCE,
			[5] = country.id.GEORGIA,
			[6] = country.id.ISRAEL,
			[7] = country.id.ITALY,
			[8] = country.id.GERMANY,
			[9] = country.id.RUSSIA,
			[10] = country.id.THE_NETHERLANDS,
			[11] = country.id.SPAIN,
			[12] = country.id.TURKEY,
			[13] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "US NAVY", "Army Standard", "US ARMY 1972", "US ARMY DOS", "US Ft. Rucker", "USA UN"}, -- liveries for ["countries"][1]
			[2] = { "Australia RAAF 171 Sqn", "Australia RAAF 1968", "Australia Royal Navy"  }, -- liveries for ["countries"][2]
			[3] = { "Canadian Force"  }, -- liveries for ["countries"][3]
			[4] = { "French Army"  }, -- liveries for ["countries"][4]
			[5] = { "Georgian AF Camo", "Georgian Air Force"  }, -- liveries for ["countries"][5]
			[6] = { "Israel Army"  }, -- liveries for ["countries"][6]
			[7] = { "Italy 15B Stormo S.A.R -Soccorso", "Italy E.I. 4B Regg. ALTAIR", "Italy Marina Militare s.n. 80951 7-20"  }, -- liveries for ["countries"][7]
			[8] = { "Luftwaffe" }, -- liveries for ["countries"][8]
			[9] = { "RF Air Force Broken", "RF Air Force Grey" }, -- liveries for ["countries"][9]
			[10] = { "Royal Netherlands AF" }, -- liveries for ["countries"][10]
			[11] = { "Spanish Army", "Spanish UN" }, -- liveries for ["countries"][11]
			[12] = { "Turkish Air Force" }, -- liveries for ["countries"][12]
			[13] = { "Ukrainian Army" }, -- liveries for ["countries"][13]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "AH-1W",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "1250.0",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL,
			[3] = country.id.TURKEY,
		},
		["liveries"] = { 
			[1] = { "standard", "USA Marines", "USA X Black" }, -- liveries for ["countries"][1]
			[2] = { "standard"  }, -- liveries for ["countries"][2]
			[3] = { "Turkey 1", "Turkey 2" }, -- liveries for ["countries"][3]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "AH-64A",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "1157",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL,
			[3] = country.id.THE_NETHERLANDS,
			[4] = country.id.UK
		},
		["liveries"] = { 
			[1] = { "standard", "standard dirty" }, -- liveries for ["countries"][1]
			[2] = { "ah-64_a_green isr"  }, -- liveries for ["countries"][2]
			[3] = { "ah-64_a_green neth" }, -- liveries for ["countries"][3]
			[4] = { "ah-64_a_green uk" }, -- liveries for ["countries"][4]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "AH-64D",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{FD90A1DC-9147-49FA-BF56-CB83EF0BD32B}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{88D18A5E-99C8-4B04-B40B-1C02F2018B6E}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "1157",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL,
			[3] = country.id.THE_NETHERLANDS,
			[4] = country.id.UK
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
			[2] = { "ah-64_d_isr"  }, -- liveries for ["countries"][2]
			[3] = { "ah-64_d_green neth" }, -- liveries for ["countries"][3]
			[4] = { "ah-64_d_green uk" }, -- liveries for ["countries"][4]
		}
	}, -- end of [4]
	[5] = {
		["type"] = "OH-58D",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "M260_HYDRA_WP",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "M260_HYDRA_WP",
				}, -- end of [2]
			}, -- end of ["pylons"]
			["fuel"] = "1100",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "" }, -- liveries for ["countries"][1]
		}
	}, -- end of [5]
	[6] = {
		["type"] = "Ka-50",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{A6FD14D3-6D30-4C85-88A7-8D17BEE120E2}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{A6FD14D3-6D30-4C85-88A7-8D17BEE120E2}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "1450",
			["flare"] = 128,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA
		},
		["liveries"] = { 
			[1] = { "Russia Standard Army", "Russia Standard Army (Worn)", "Russia Worn Black" }, -- liveries for ["countries"][1]
		}
	}, -- end of [6]
	[7] = {
		["type"] = "Mi-24V",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{B919B0F4-7C25-455E-9A02-CEA51DB895E3}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{B919B0F4-7C25-455E-9A02-CEA51DB895E3}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = "1704",
			["flare"] = 192,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE,
			[3] = country.id.ABKHAZIA,
			[4] = country.id.GEORGIA,
			[5] = country.id.SOUTH_OSETIA
		},
		["liveries"] = { 
			[1] = { "standard 1", "standard 2 (faded and sun-bleached)" }, -- liveries for ["countries"][1]
			[2] = { "ukraine" }, -- liveries for ["countries"][2]
			[3] = { "Abkhazia" }, -- liveries for ["countries"][3]
			[4] = { "standard" }, -- liveries for ["countries"][4]
			[4] = { "South Ossetia" }, -- liveries for ["countries"][4]
		}
	}, -- end of [7]
	[8] = {
		["type"] = "Mi-28N",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{57232979-8B0F-4db7-8D9A-55197E06B0F5}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{57232979-8B0F-4db7-8D9A-55197E06B0F5}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "1500",
			["flare"] = 128,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "standard", "night" }, -- liveries for ["countries"][1]
		}
	}, -- end of [8]
	[9] = {
		["type"] = "Mi-8MT",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{05544F1A-C39C-466b-BC37-5BD1D52E57BB}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{05544F1A-C39C-466b-BC37-5BD1D52E57BB}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{6A4B9E69-64FE-439a-9163-3A87FB6A4D81}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = "1929",
			["flare"] = 192,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "Russia_Army_Weather", "Russia_Naryan-Mar", "Russia_VVS_Grey", "Russia_VVS_Standard" }, -- liveries for ["countries"][1]
			[2] = { "Ukraine" }, -- liveries for ["countries"][2]
		}
	}, -- end of [9]
} -- end of RTHelicoptersAttack
RTHelicoptersTransport = {
	[1] = {
		["type"] = "CH-47D",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "7937",
			["flare"] = 120,
			["chaff"] = 12,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.AUSTRALIA,
			[3] = country.id.SPAIN,
			[4] = country.id.UK,
			[5] = country.id.THE_NETHERLANDS,
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
			[2] = { "Australia RAAF" }, -- liveries for ["countries"][2]
			[3] = { "ch-47_green spain" }, -- liveries for ["countries"][3]
			[4] = { "ch-47_green uk" }, -- liveries for ["countries"][4]
			[5] = { "ch-47_green neth" } -- liveries for ["countries"][5]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "CH-53E",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "4206",
			["flare"] = 60,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "SH-60B",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "2425",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "UH-60A",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "2425",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
			[2] = { "ISRAIL_UN" }, -- liveries for ["countries"][2]
		}
	}, -- end of [4]
	[5] = {
		["type"] = "Ka-27",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "5767",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "standard" }, -- liveries for ["countries"][1]
			[2] = { "ukraine camo 1" }, -- liveries for ["countries"][2]
		}
	}, -- end of [5]
	[6] = {
		["type"] = "Mi-26",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "21164",
			["flare"] = 192,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "RF Air Force" }, -- liveries for ["countries"][1]
			[2] = { "7th Separate Brigade of AA (Kalinov)" }, -- liveries for ["countries"][2]
		}
	}, -- end of [6]
	[7] = {
		["type"] = "Mi-8MT",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "4253",
			["flare"] = 192,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "Russia_Army_Weather", "Russia_Naryan-Mar", "Russia_VVS_Grey", "Russia_VVS_Standard" }, -- liveries for ["countries"][1]
			[2] = { "Ukraine" }, -- liveries for ["countries"][2]
		}
	}, -- end of [7]
} -- end of RTHelicoptersTransport
RTHelicoptersCivilian = {
	[1] = {
		["type"] = "UH-1H",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "631",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 0,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.BELGIUM,
			[3] = country.id.NORWAY,
			[4] = country.id.DENMARK,
			[5] = country.id.UK,
			[6] = country.id.ABKHAZIA,
			[7] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "[Civilian] Medical", "[Civilian] NASA", "[Civilian] Standard", "[Civilian] VIP", "XW-PFJ Air America" }, -- liveries for ["countries"][1]
			[2] = { "[Civilian] Standard" }, -- liveries for ["countries"][2]
			[3] = { "[Civilian] Standard" }, -- liveries for ["countries"][3]
			[4] = { "[Civilian] Standard" }, -- liveries for ["countries"][4]
			[5] = { "[Civilian] Standard" }, -- liveries for ["countries"][5]
			[6] = { "[Civilian] Standard" }, -- liveries for ["countries"][6]
			[7] = { "[Civilian] Medical", "[Civilian] NASA", "[Civilian] Standard", "[Civilian] VIP", "XW-PFJ Air America" }, -- liveries for ["countries"][7]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "Mi-26",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "21164",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "Russia_FSB", "Russia_MVD" }, -- liveries for ["countries"][1]
			[2] = { "Russia_FSB", "Russia_MVD" }, -- liveries for ["countries"][2]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "Mi-8MT",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "4253",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "Russia_FSB", "Russia_MVD_Mozdok", "Russia_MVD_Standard" }, -- liveries for ["countries"][1]
			[2] = { "Russia_FSB", "Russia_MVD_Mozdok", "Russia_MVD_Standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "Mi-24V",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
			}, -- end of ["pylons"]
			["fuel"] = "1704",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "Russia_FSB", "Russia_MVD" }, -- liveries for ["countries"][1]
			[2] = { "Russia_FSB", "Russia_MVD" }, -- liveries for ["countries"][2]
		}
	}, -- end of [4]
} -- end of RTHelicoptersCivilian
RTFighters = {
	[1] = {
		["type"] = "F-15C",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
				[1] =
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [1]
				[2] =
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [2]
				[3] =
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[4] =
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [4]
				[5] =
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [5]
				[6] =
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [6]
				[7] =
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [7]
				[8] =
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [8]
				[9] =
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [9]
				[10] =
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [10]
				[11] =
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [11]
			}, -- end of ["pylons"]
			["fuel"] = "6103",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL
		},
		["liveries"] = { 
			[1] = { "12th Fighter SQN (AK)", "390th Fighter SQN", "493rd Fighter SQN (LN)", "58th Fighter SQN (EG)",
				"65th Aggressor SQN (WA) Flanker", "65th Aggressor SQN (WA) MiG", "65th Aggressor SQN (WA) SUPER_Flanker", "Ferris Scheme"
			}, -- liveries for ["countries"][1]
			[2] = { "106th SQN (8th Airbase)" } -- liveries for ["countries"][2]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "Su-27",
		["active"] = true,
		["payload"] = {
			["pylons"] = {
				[1] =
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [1]
				[2] =
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] =
				{
					["CLSID"] = "{B79C379A-9E87-4E50-A1EE-7F7E29C2E87A}",
				}, -- end of [3]
				[4] =
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [4]
				[5] =
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [5]
				[6] =
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [6]
				[7] =
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [7]
				[8] =
				{
					["CLSID"] = "{B79C379A-9E87-4E50-A1EE-7F7E29C2E87A}",
				}, -- end of [8]
				[9] =
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [9]
				[10] =
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "9400",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.CHINA,
			[3] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "Air Force Standard", "Air Force Standard Early", "Air Force Standard old", "Besovets AFB", "Besovets AFB 2 squadron",
				"Chkalovsk AFB (689 GvIAP)", "Hotilovo AFB", "Kazakhstan Air Defense Forces", "Klipyavr AFB (Maresyev)",
				"Kubinka AFB (Russian Knights Old)", "Kubinka AFB (Russion Knights)", "Lodeynoye pole AFB (177 IAP)",
				"Lypetsk AFB (Falcons of Russia)", "Lypetsk AFB (Shark)", "M Gromov FRI"
			}, -- liveries for ["countries"][1]
			[2] = { "PLAAF K1S old", "PLAAF K2S new", "PLAAF K2S old", "PLAAF K33S", "PLAAF Standard", "PLANAF HH8S" }, -- liveries for ["countries"][2]
			[3] = { "Air Force Ukraine Standard", "Air Force Ukraine Early", "Mirgorod AFB (831th brigade)", 
				"Mirgorod AFB (Digital camo)", "Ozerne AFB (9th brigade)"
			} -- liveries for ["countries"][3]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "Tornado GR4",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{8C3F26A2-FA0F-11d5-9190-00A0249B6F00}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{EF124821-F9BB-4314-A153-E0E2FE1162C4}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{0D33DDAE-524F-4A4E-B5B8-621754FE3ADE}",
				}, -- end of [4]
				[11] = 
				{
					["CLSID"] = "{EF124821-F9BB-4314-A153-E0E2FE1162C4}",
				}, -- end of [11]
				[10] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [10]
				[12] = 
				{
					["CLSID"] = "{8C3F26A1-FA0F-11d5-9190-00A0249B6F00}",
				}, -- end of [12]
				[9] = 
				{
					["CLSID"] = "{0D33DDAE-524F-4A4E-B5B8-621754FE3ADE}",
				}, -- end of [9]
			}, -- end of ["pylons"]
			["fuel"] = "4663",
			["flare"] = 45,
			["chaff"] = 90,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.UK,
		},
		["liveries"] = { 
			[1] = { "bb of 14 squadron raf lossiemouth", "no. 9 squadron raf marham ab (norfolk)",
				"no. 12 squadron raf lossiemouth ab (morayshire)", "no. 14 squadron raf lossiemouth ab (morayshire)",
				"no. 617 squadron raf lossiemouth ab (morayshire)", "o of ii (ac) squadron raf marham"
			}, -- liveries for ["countries"][1]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "F-4E",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{7B4B122D-C12C-4DB4-834E-4D8BB4D863A8}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{9DDF5297-94B9-42FC-A45E-6E316121CD85}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [4]
				[6] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{9DDF5297-94B9-42FC-A45E-6E316121CD85}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{7B4B122D-C12C-4DB4-834E-4D8BB4D863A8}",
				}, -- end of [9]
			}, -- end of ["pylons"]
			["fuel"] = "4864",
			["flare"] = 30,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.GERMANY,
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
		}
	}, -- end of [4]
	[5] = {
		["type"] = "Tornado IDS",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{8C3F26A1-FA0F-11d5-9190-00A0249B6F00}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{EF124821-F9BB-4314-A153-E0E2FE1162C4}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[5] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [8]
				[10] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{EF124821-F9BB-4314-A153-E0E2FE1162C4}",
				}, -- end of [11]
				[12] = 
				{
					["CLSID"] = "{8C3F26A1-FA0F-11d5-9190-00A0249B6F00}",
				}, -- end of [12]
			}, -- end of ["pylons"]
			["fuel"] = "4663",
			["flare"] = 45,
			["chaff"] = 90,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.GERMANY,
			[2] = country.id.ITALY
		},
		["liveries"] = { 
			[1] = { "aufklarungsgeschwader 51 `immelmann` jagel ab luftwaffe", "jagdbombergeschwader 31 `boelcke` norvenich ab luftwaffe",
				"jagdbombergeschwader 32 lechfeld ab luftwaffe", "jagdbombergeschwader 33 buchel ab no. 43+19 experimental scheme",
				"marinefliegergeschwader 2 eggebek ab marineflieger"
			}, -- liveries for ["countries"][1]
			[2] = { "ITA Tornado (Sesto Stormo Diavoli Rossi)", "ITA Tornado Black",
				"ITA Tornado MM7042", "ITA Tornado MM55004"
			} -- liveries for ["countries"][2]
		}
	}, -- end of [5]
	[6] = {
		["type"] = "F-16A MLU",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [4]
				[6] = 
				{
					["CLSID"] = "{6D21ECEA-F85B-4E8D-9D51-31DC9B8AA4EF}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "3104",
			["flare"] = 30,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.BELGIUM,
			[2] = country.id.NORWAY,
			[3] = country.id.DENMARK,
			[4] = country.id.THE_NETHERLANDS
		},
		["liveries"] = { 
			[1] = { "2nd squadron `comet` florennes ab"	}, -- liveries for ["countries"][1]
			[2] = { "norway 338 skvadron", "norway skv338" }, -- liveries for ["countries"][2]
			[3] = { "rdaf f16 standard-1" }, -- liveries for ["countries"][3]
			[4] = { "the netherlands (313th squadron `` twenthe ab)", "the netherlands 313th `tigers` squadron" } -- liveries for ["countries"][4]
		}
	}, -- end of [6]
	[7] = {
		["type"] = "A-10C",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "ALQ_184",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{319293F2-392C-4617-8315-7C88C22AF7C4}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{E6A6262A-CA08-4B3D-B030-E1A993B98452}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{DB769D48-67D7-42ED-A2BE-108D566C8B1E}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{GBU-38}",
				}, -- end of [5]
				[7] = 
				{
					["CLSID"] = "{GBU-38}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{DB769D48-67D7-42ED-A2BE-108D566C8B1E}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{E6A6262A-CA08-4B3D-B030-E1A993B98453}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{A111396E-D3E8-4b9c-8AC9-2432489304D5}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{DB434044-F5D0-4F1F-9BA9-B73027E18DD3}",
				}, -- end of [11]
			}, -- end of ["pylons"]
			["fuel"] = 5029,
			["flare"] = 120,
			["ammo_type"] = 1,
			["chaff"] = 240,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.AUSTRALIA,
			[3] = country.id.CANADA,
			[4] = country.id.TURKEY,
			[5] = country.id.UK,
			[6] = country.id.THE_NETHERLANDS,
			[7] = country.id.BELGIUM,
			[8] = country.id.DENMARK
		},
		["liveries"] = { 
			[1] = { "23rd TFW England AFB (EL)", "25th FS Osan AB, Korea (OS)", "47th FS Barksdale AFB, Louisiana (BD)",
				"66th WS Nellis AFB, Nevada (WA)", "74th FS Moody AFB, Georgia (FT)", "81st FS Spangdahlem AB, Germany (SP) 1",
				"81st FS Spangdahlem AB, Germany (SP) 2", "104th FS Maryland ANG, Baltimore (MD)", "118th FS Bradley ANGB, Connecticut (CT)",
				"118th FS Bradley ANGB, Connecticut (CT) N621", "172nd FS Battle Creek ANGB, Michigan (BC)", 
				"184th FS Arkansas ANG, Fort Smith (FS)", "190th FS Boise ANGB, Idaho (ID)", "354th FS Davis Monthan AFB, Arizona (DM)",
				"355th FS Eielson AFB, Alaska (AK)", "357th FS Davis Monthan AFB, Arizona (DM)", "358th FS Davis Monthan AFB, Arizona (DM)",
				"422nd TES Nellis AFB, Nevada (OT)"
			}, -- liveries for ["countries"][1]
			[2] = { "Australia Notional RAAF" }, -- liveries for ["countries"][2]
			[3] = { "Canada RCAF 409 Squadron", "Canada RCAF 442 Snow Scheme" }, -- liveries for ["countries"][3]
			[4] = { "A-10 Grey" }, -- liveries for ["countries"][4]
			[5] = { "A-10 Grey" }, -- liveries for ["countries"][5]
			[6] = { "A-10 Grey" }, -- liveries for ["countries"][6]
			[7] = { "A-10 Grey" }, -- liveries for ["countries"][7]
			[8] = { "A-10 Grey" }, -- liveries for ["countries"][8]
		}
	}, -- end of [7]
	[8] = {
		["type"] = "F-14A",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [2]
				[4] = 
				{
					["CLSID"] = "{7575BA0B-7294-4844-857B-031A144B2595}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{7575BA0B-7294-4844-857B-031A144B2595}",
				}, -- end of [5]
				[8] = 
				{
					["CLSID"] = "{7575BA0B-7294-4844-857B-031A144B2595}",
				}, -- end of [8]
				[11] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [11]
				[9] = 
				{
					["CLSID"] = "{7575BA0B-7294-4844-857B-031A144B2595}",
				}, -- end of [9]
				[12] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [12]
			}, -- end of ["pylons"]
			["fuel"] = "7348",
			["flare"] = 15,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
		},
		["liveries"] = { 
			[1] = { "vf-1 `wolfpack`", "vf-33 `starfighters`", "vf-41 `black aces`", "vf-84 `jolly rogers`",
				"vf-111 `sundowners`- 1", "vf-111 `sundowners`- 2", "vf-142 `ghost riders`", "vf-143 `pukin's dogs`",
				"vf-xxx `aardvarks`"
			}, -- liveries for ["countries"][1]
		}
	}, -- end of [8]
	[9] = {
		["type"] = "F-15E",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [11]
				[12] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [12]
				[13] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [13]
				[14] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [14]
				[15] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [15]
				[16] = 
				{
					["CLSID"] = "{BCE4E030-38E9-423E-98ED-24BE3DA87C32}",
				}, -- end of [16]
				[17] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [17]
				[18] = 
				{
					["CLSID"] = "{E1F29B21-F291-4589-9FD8-3272EEC69506}",
				}, -- end of [18]
				[19] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [19]
			}, -- end of ["pylons"]
			["fuel"] = "10246",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL
		},
		["liveries"] = { 
			[1] = { "335th Fighter SQN (SJ)", "492d Fighter SQN (LN)" }, -- liveries for ["countries"][1]
			[2] = { "IDF No 69 Hammers Squadron" }, -- liveries for ["countries"][2]
		}
	}, -- end of [9]
	[10] = {
		["type"] = "F-16A",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [4]
				[6] = 
				{
					["CLSID"] = "{6D21ECEA-F85B-4E8D-9D51-31DC9B8AA4EF}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "3104",
			["flare"] = 30,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.DENMARK
		},
		["liveries"] = { 
			[1] = { "usaf f16 standard-1" }, -- liveries for ["countries"][1]
			[2] = { "standard_denmark" }, -- liveries for ["countries"][2]
		}
	}, -- end of [10]
	[11] = {
		["type"] = "F-16C bl.52d",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [4]
				[6] = 
				{
					["CLSID"] = "ALQ_184",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{F376DBEE-4CAE-41BA-ADD9-B2910AC95DEC}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{40EF17B7-F508-45de-8566-6FFECC0C1AB8}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "3104",
			["flare"] = 45,
			["chaff"] = 90,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.ISRAEL
		},
		["liveries"] = { 
			[1] = { "pacaf 14th fs (mj) misawa afb", "pacaf 35th fw (ww) misawa afb", "usaf 77th fs (sw) shaw afb",
				"usaf 147th fig (ef) ellington afb", "usaf 412th tw (ed) edwards afb", "usaf 414th cts (wa) nellis afb",
				"usafe 22nd fs (sp) spangdahlem afb", "usafe 555th fs (av) aviano afb"
			}, -- liveries for ["countries"][1]
			[2] = { "idf_af f16c standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [11]
	[12] = {
		["type"] = "F-86F Sabre",
		["active"] = false,
		["payload"] = 
		{
			["pylons"] = 
			{
				[5] = 
				{
					["CLSID"] = "{GAR-8}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{GAR-8}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{PTB_120_F86F35}",
				}, -- end of [7]
				[4] = 
				{
					["CLSID"] = "{PTB_120_F86F35}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = 1282,
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
		},
		["liveries"] = { 
			[1] = { "US Air Force", "US Air Force (code FU-178)", "US Air Force (ex-USAF F-86A Sabre)" }, -- liveries for ["countries"][1]
		}
	}, -- end of [12]
	[13] = {
		["type"] = "F/A-18C",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{EFEC8201-B922-11d7-9897-000476191836}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{EFEC8201-B922-11d7-9897-000476191836}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{8D399DDA-FF81-4F14-904D-099B34FE7918}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{EFEC8201-B922-11d7-9897-000476191836}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{C8E06185-7CD6-4C90-959F-044679E90751}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [9]
			}, -- end of ["pylons"]
			["fuel"] = "6531",
			["flare"] = 15,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.AUSTRALIA
		},
		["liveries"] = { 
			[1] = { "NSAWC_25", "NSAWC_44", "VFA-94", "VFC-12" }, -- liveries for ["countries"][1]
			[2] = { "Australia 75 Sqn RAAF" }, -- liveries for ["countries"][2]
		}
	}, -- end of [13]
	[14] = {
		["type"] = "Hawk",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[2] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{05544F1A-C39C-466b-BC37-5BD1D52E57BB}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{6CEB49FC-DED8-4DED-B053-E1F033FF72D3}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = 1272,
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.UK,
			[3] = country.id.SWITZERLAND,
			[4] = country.id.FINLAND
		},
		["liveries"] = { 
			[1] = { "12th FTW, Randolph AFB, Texas (RA)", "1st RS, Beale AFB, California (BB)",
				"25th FTS, Vance AFB, Oklahoma (VN)", "509th BS, Whitman AFB, Missouri (WM)",
				"88th FTS, Sheppard AFB, Texas (EN)", "NAS Meridian Mississippi Seven (VT-7)"
			}, -- liveries for ["countries"][1]
			[2] = { "XX226 - 74Sqn 1992-2000", "XX316 - 74Sqn 1998-2000", "XX218 - 208Sqn",
				"XX175 - FRADU Royal Navy", "XX316 - FRADU Royal Navy"
			}, -- liveries for ["countries"][2]
			[3] = { "Swiss U-1251 - White", "Swiss U-1252 - Normal", "Swiss U-1268 - ByeByeHawk",
				"Swiss U-1270 - Wallis"
			}, -- liveries for ["countries"][3]
			[4] = { "Finland HW-341 Grey", "Finland HW-373 Ex-Swiss Air Force" }, -- liveries for ["countries"][4]
		}
	}, -- end of [14]
	[15] = {
		["type"] = "L-39C",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [1]
				[3] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [3]
			}, -- end of ["pylons"]
			["fuel"] = 823.2,
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.GERMANY,
			[3] = country.id.UKRAINE,
			[4] = country.id.CHEZH_REPUBLIC
		},
		["liveries"] = { 
			[1] = { "Russ Jet Team", "Russian Air Force", "Russian Air Force Navy", "Russian Air Force Old" }, -- liveries for ["countries"][1]
			[2] = { "DDR Luftwaffe", "DDR Luftwaffe Early" }, -- liveries for ["countries"][2]
			[3] = { "Ukraine Air Force UKHW" }, -- liveries for ["countries"][3]
			[4] = { "Czech Air Force", "Czech Air Force CLV", "Czechoslovakia Air Force" }, -- liveries for ["countries"][4]
		}
	}, -- end of [15]
	[16] = {
		["type"] = "M-2000C",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{FC23864E-3B80-48E3-9C03-4DA8B1D7497B}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FD21B13E-57F3-4C2A-9F78-C522D0B5BCE1}",
				}, -- end of [2]
				[5] = 
				{
					["CLSID"] = "{M2KC_RPL_522}",
				}, -- end of [5]
				[9] = 
				{
					["CLSID"] = "{FC23864E-3B80-48E3-9C03-4DA8B1D7497B}",
				}, -- end of [9]
				[8] = 
				{
					["CLSID"] = "{FD21B13E-57F3-4C2A-9F78-C522D0B5BCE1}",
				}, -- end of [8]
			}, -- end of ["pylons"]
			["fuel"] = 3165,
			["flare"] = 16,
			["chaff"] = 112,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.FRANCE,
			[2] = country.id.GREECE,
			[3] = country.id.SAUDI_ARABIA			
		},
		["liveries"] = { 
			[1] = { "AdA Chasse 2/5" }, -- liveries for ["countries"][1]
			[2] = { "Polemikh Aeroporia (Greek Air Force)" }, -- liveries for ["countries"][2]
			[3] = { "UAE Air Defense Air Force" }, -- liveries for ["countries"][3]
		}
	}, -- end of [16]
	[17] = {
		["type"] = "MiG-15bis",
		["active"] = false,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "PTB400_MIG15",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "PTB400_MIG15",
				}, -- end of [2]
			}, -- end of ["pylons"]
			["fuel"] = 1172,
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.NORTH_KOREA,
			[3] = country.id.CHINA,
			[4] = country.id.CHEZH_REPUBLIC,
			[5] = country.id.GERMANY,
			[6] = country.id.POLAND
		},
		["liveries"] = { 
			[1] = { "USSR_Air Forces", "USSR_Pepalyaev", "USSR_Red" }, -- liveries for ["countries"][1]
			[2] = { "North_Korea_Air Force", "North_Korea_Air Force_Major_Arkady_Boitsow" }, -- liveries for ["countries"][2]
			[3] = { "China Volunteer Air Force", "China_Air Force" }, -- liveries for ["countries"][3]
			[4] = { "Czechoslovakia_Air Force" }, -- liveries for ["countries"][4]
			[5] = { "GDR_Air Force" }, -- liveries for ["countries"][5]
			[6] = { "Polish_Air Force" }, -- liveries for ["countries"][6]
		}
	}, -- end of [17]
	[18] = {
		["type"] = "MiG-21Bis",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{R-60M 2L}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{R-3R}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{PTB_800_MIG21}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{R-3R}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{R-60M 2R}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{ASO-2}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = 2280,
			["flare"] = 32,
			["ammo_type"] = 1,
			["chaff"] = 32,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.SERBIA,
			[3] = country.id.BULGARIA,
			[4] = country.id.CROATIA,
			[5] = country.id.EGYPT,
			[6] = country.id.FINLAND,
			[7] = country.id.GERMANY,
			[8] = country.id.INDIA,
			[9] = country.id.POLAND
		},
		["liveries"] = { 
			[1] = { "VVS Camo", "VVS Grey" }, -- liveries for ["countries"][1]
			[2] = { "Serbia - 101 FS" }, -- liveries for ["countries"][2]
			[3] = { "Bulgaria" }, -- liveries for ["countries"][3]
			[4] = { "Croatia - 1992" }, -- liveries for ["countries"][4]
			[5] = { "Egypt Grey", "Egypt Tan" }, -- liveries for ["countries"][5]
			[6] = { "Finland - HavLLv 31" }, -- liveries for ["countries"][6]
			[7] = { "Germany East" }, -- liveries for ["countries"][7]
			[8] = { "India - 15 Sqn" }, -- liveries for ["countries"][8]
			[9] = { "Poland - 1 DLMW", "Poland - Metal" }, -- liveries for ["countries"][9]
		}
	}, -- end of [18]
	[19] = {
		["type"] = "S-3B",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{8B7CADF9-4954-46B3-8CFB-93F2F5B90B03}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{AB8B8299-F1CC-4359-89B5-2172E0CF4A5A}",
				}, -- end of [2]
				[5] = 
				{
					["CLSID"] = "{AB8B8299-F1CC-4359-89B5-2172E0CF4A5A}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{8B7CADF9-4954-46B3-8CFB-93F2F5B90B03}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = "5500",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
		},
		["liveries"] = { 
			[1] = { "usaf standard" }, -- liveries for ["countries"][1]
		}
	}, -- end of [19]
	[20] = {
		["type"] = "Mirage 2000-5",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{FC23864E-3B80-48E3-9C03-4DA8B1D7497B}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{414DA830-B61A-4F9E-B71B-C2F6832E1D7A}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{6D778860-7BB8-4ACB-9E95-BA772C6BBC2C}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{0DA03783-61E4-40B2-8FAE-6AEE0A5C5AAE}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{414DA830-B61A-4F9E-B71B-C2F6832E1D7A}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{0DA03783-61E4-40B2-8FAE-6AEE0A5C5AAE}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{6D778860-7BB8-4ACB-9E95-BA772C6BBC2C}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{414DA830-B61A-4F9E-B71B-C2F6832E1D7A}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{FC23864E-3B80-48E3-9C03-4DA8B1D7497B}",
				}, -- end of [9]
			}, -- end of ["pylons"]
			["fuel"] = "3160",
			["flare"] = 16,
			["chaff"] = 112,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.FRANCE,
		},
		["liveries"] = { 
			[1] = { "ec1_2  spa12 `cigogne a ailes ouvertes`", "ec1_2  spa103 `cigogne de fonck`",
				"ec1_2 spa3 `cigogne de guynemer`", "ec2_2 `cote d'or` spa57 `mouette`",
				"ec2_2 `cote d'or` spa65 `chimere`", "ec2_2 spa94 `lamort qui fauche`"
			}, -- liveries for ["countries"][1]
		}
	}, -- end of [20]
	[21] = {
		["type"] = "L-39ZA",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [2]
				[4] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{R-3S}",
				}, -- end of [5]
			}, -- end of ["pylons"]
			["fuel"] = 823.2,
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.ABKHAZIA,
			[3] = country.id.CHEZH_REPUBLIC,
			[4] = country.id.GEORGIA,
			[5] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "Russian Air Force 1", "Russian Air Force Old" }, -- liveries for ["countries"][1]
			[2] = { "Abkhazian Air Force" }, -- liveries for ["countries"][2]
			[3] = { "Czech Air Force" }, -- liveries for ["countries"][3]
			[4] = { "Georgian Air Force" }, -- liveries for ["countries"][4]
			[5] = { "Ukraine Air Force 1" }, -- liveries for ["countries"][5]
		}
	}, -- end of [21]
	[22] = {
		["type"] = "MiG-23MLD",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[2] = 
				{
					["CLSID"] = "{CCF898C9-5BC7-49A4-9D1E-C3ED3D5166A1}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{B0DBC591-0F52-4F7D-AD7B-51E67725FB81}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{A5BAEAB7-6FAF-4236-AF72-0FD900F493F9}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{275A2855-4A79-4B2D-B082-91EA2ADF4691}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{CCF898C9-5BC7-49A4-9D1E-C3ED3D5166A1}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = "3800",
			["flare"] = 60,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard", "af standard-1", "af standard-2", "af standard-3 (worn-out)" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [22]
	[23] = {
		["type"] = "MiG-25PD",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{4EDBA993-2E34-444C-95FB-549300BF7CAF}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{4EDBA993-2E34-444C-95FB-549300BF7CAF}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "15245",
			["flare"] = 64,
			["chaff"] = 64,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [23]
	[24] = {
		["type"] = "MiG-25RBT",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [1]
				[4] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [4]
			}, -- end of ["pylons"]
			["fuel"] = "15245",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [24]
	[25] = {
		["type"] = "MiG-27K",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[2] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{3C612111-C7AD-476E-8A8E-2485812F4E5C}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{A5BAEAB7-6FAF-4236-AF72-0FD900F493F9}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{3C612111-C7AD-476E-8A8E-2485812F4E5C}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [8]
			}, -- end of ["pylons"]
			["fuel"] = "4500",
			["flare"] = 60,
			["chaff"] = 60,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [25]
	[26] = {
		["type"] = "MiG-29A",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{9B25D316-0434-4954-868F-D51DB1A38DF0}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{2BEC576B-CDF5-4B7F-961F-B0FA4312B841}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{9B25D316-0434-4954-868F-D51DB1A38DF0}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [7]
			}, -- end of ["pylons"]
			["fuel"] = "3380",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE,
			[3] = country.id.GERMANY
		},
		["liveries"] = { 
			[1] = { "`swifts` team #44 kubinka ab", "120 gviap #45 domna ab" }, -- liveries for ["countries"][1]
			[2] = { "40th fw `maestro` vasilkov ab", "af standard-1", "af standard-2" }, -- liveries for ["countries"][2]
			[3] = { "33th iap wittstock ab (germany)", "968th iap altenburg ab (germany)", "luftwaffe 29+20 demo",
				"luftwaffe gray early", "luftwaffe gray-1", "luftwaffe gray-2(worn-out)", "luftwaffe gray-3", "luftwaffe gray-4"
			}, -- liveries for ["countries"][3]
		}
	}, -- end of [26]
	[27] = {
		["type"] = "MiG-29S",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{2BEC576B-CDF5-4B7F-961F-B0FA4312B841}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [7]
			}, -- end of ["pylons"]
			["fuel"] = "3500",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE,
		},
		["liveries"] = { 
			[1] = { "2nd fs `swifts` team, kubinka ab", "4th ctc lypetsk ab", "73th guards regiment, merzeburg ab (gdr)",
				"115th guards regiment, termez ab", "120th guards regiment, domna ab", "733th guards regiment, damgarten ab (gdr)",
				"1038th guards ctc, mary ab"
			}, -- liveries for ["countries"][1]
			[2] = { "`ukrainian falcons` paint scheme", "9th fw belbek ab", "14th army, vinnitsa ab" }, -- liveries for ["countries"][2]			
		}
	}, -- end of [27]
	[28] = {
		["type"] = "MiG-31",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{B0DBC591-0F52-4F7D-AD7B-51E67725FB81}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{F1243568-8EF0-49D4-9CB5-4DA90D92BC1D}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{F1243568-8EF0-49D4-9CB5-4DA90D92BC1D}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F1243568-8EF0-49D4-9CB5-4DA90D92BC1D}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{F1243568-8EF0-49D4-9CB5-4DA90D92BC1D}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{275A2855-4A79-4B2D-B082-91EA2ADF4691}",
				}, -- end of [6]
			}, -- end of ["pylons"]
			["fuel"] = "15500",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "174 GvIAP_Boris Safonov", "af standard" }, -- liveries for ["countries"][1]
		}
	}, -- end of [28]
	[29] = {
		["type"] = "Su-17M4",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{A5BAEAB7-6FAF-4236-AF72-0FD900F493F9}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{A5BAEAB7-6FAF-4236-AF72-0FD900F493F9}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [8]
			}, -- end of ["pylons"]
			["fuel"] = "3770",
			["flare"] = 64,
			["chaff"] = 64,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard (RUS)", "af standard (worn-out) (RUS)" }, -- liveries for ["countries"][1]
			[2] = { "af standard", "af standard (worn-out)", "shap lomanskoye ab" }, -- liveries for ["countries"][2]
		}
	}, -- end of [29]
	[30] = {
		["type"] = "Su-24M",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [3]
				[5] = 
				{
					["CLSID"] = "{16602053-4A12-40A2-B214-AB60D481B20E}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [8]
			}, -- end of ["pylons"]
			["fuel"] = "11700",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [30]
	[31] = {
		["type"] = "Su-24MR",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{B0DBC591-0F52-4F7D-AD7B-51E67725FB81}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{7D7EC917-05F6-49D4-8045-61FC587DD019}",
				}, -- end of [2]
				[5] = 
				{
					["CLSID"] = "{0519A262-0AB6-11d6-9193-00A0249B6F00}",
				}, -- end of [5]
				[7] = 
				{
					["CLSID"] = "{7D7EC917-05F6-49D4-8045-61FC587DD019}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{0519A261-0AB6-11d6-9193-00A0249B6F00}",
				}, -- end of [8]
			}, -- end of ["pylons"]
			["fuel"] = "11700",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "af standard" }, -- liveries for ["countries"][1]
			[2] = { "af standard" }, -- liveries for ["countries"][2]
		}
	}, -- end of [31]
	[32] = {
		["type"] = "Su-25",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{E8D4652F-FD48-45B7-BA5B-2AE05BB5A9CF}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{E8D4652F-FD48-45B7-BA5B-2AE05BB5A9CF}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "2835",
			["flare"] = 128,
			["chaff"] = 128,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.UKRAINE,
			[3] = country.id.ABKHAZIA,
			[4] = country.id.GEORGIA
		},
		["liveries"] = { 
			[1] = { "field camo scheme #1 (native)", "field camo scheme #2 (native). 960th shap",
				"field camo scheme #3 (worn-out). 960th shap", "forest camo scheme #1 (native)"
			}, -- liveries for ["countries"][1]
			[2] = { "broken camo scheme #1 (native). 299th oshap", "broken camo scheme #2 (native). 452th shap",
				"petal camo scheme #1 (native). 299th brigade", "petal camo scheme #2 (native). 299th brigade"
			}, -- liveries for ["countries"][2]
			[3] = { "Abkhazian Air Force" }, -- liveries for ["countries"][3]
			[4] = { "field camo scheme #1 (native)01" } -- liveries for ["countries"][4]
		}
	}, -- end of [32]
	[33] = {
		["type"] = "Su-25T",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{44EE8698-89F9-48EE-AF36-5FD31896A82D}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{CBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{0180F983-C14A-11d8-9897-000476191836}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F789E86A-EE2E-4E6B-B81E-D5E5F903B6ED}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{E92CBFE5-C153-11d8-9897-000476191836}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{B1EF6B0E-3D91-4047-A7A5-A99E7D8B4A8B}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{E92CBFE5-C153-11d8-9897-000476191836}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{F789E86A-EE2E-4E6B-B81E-D5E5F903B6ED}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{0180F983-C14A-11d8-9897-000476191836}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{CBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{44EE8698-89F9-48EE-AF36-5FD31896A82C}",
				}, -- end of [11]
			}, -- end of ["pylons"]
			["fuel"] = "3790",
			["flare"] = 128,
			["chaff"] = 128,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.GEORGIA
		},
		["liveries"] = { 
			[1] = { "af standard 1", "af standard 2" }, -- liveries for ["countries"][1]
			[2] = { "af standard", "af standard 101" }, -- liveries for ["countries"][2]
		}
	}, -- end of [33]
	[34] = {
		["type"] = "Su-25TM",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{E8D4652F-FD48-45B7-BA5B-2AE05BB5A9CF}",
				}, -- end of [5]
				[7] = 
				{
					["CLSID"] = "{E8D4652F-FD48-45B7-BA5B-2AE05BB5A9CF}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{637334E4-AB5A-47C0-83A6-51B7F1DF3CD5}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{682A481F-0CB5-4693-A382-D00DD4A156D7}",
				}, -- end of [11]
			}, -- end of ["pylons"]
			["fuel"] = "3790",
			["flare"] = 128,
			["chaff"] = 128,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "Flight Research Institute  VVS" }, -- liveries for ["countries"][1]
		}
	}, -- end of [34]
	[35] = {
		["type"] = "Su-30",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [10]
			}, -- end of ["pylons"]
			["fuel"] = "9400",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "`russian knights` team #25", "`test-pilots` team #597", "adf 148th ctc savasleyka ab",
				"af standard", "af standard early", "af standard early (worn-out)", "af standard last", "af standard last (worn-out)"
			}, -- liveries for ["countries"][1]
		}
	}, -- end of [35]
	[36] = {
		["type"] = "Su-33",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{B79C379A-9E87-4E50-A1EE-7F7E29C2E87A}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{E8069896-8435-4B90-95C0-01A03AE6E400}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{B79C379A-9E87-4E50-A1EE-7F7E29C2E87A}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [11]
				[12] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [12]
			}, -- end of ["pylons"]
			["fuel"] = "9400",
			["flare"] = 48,
			["chaff"] = 48,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "279th kiap 1st squad navy", "279th kiap 2nd squad navy",
				"standard-1 navy", "standard-2 navy"
			}, -- liveries for ["countries"][1]
		}
	}, -- end of [36]
	[37] = {
		["type"] = "Su-34",
		["active"] = true,
		["payload"] = 
		{
			["pylons"] = 
			{
				[1] = 
				{
					["CLSID"] = "{44EE8698-89F9-48EE-AF36-5FD31896A82F}",
				}, -- end of [1]
				[2] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [2]
				[3] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [3]
				[4] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [4]
				[5] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [5]
				[6] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [6]
				[7] = 
				{
					["CLSID"] = "{B4C01D60-A8A3-4237-BD72-CA7655BC0FE9}",
				}, -- end of [7]
				[8] = 
				{
					["CLSID"] = "{D5435F26-F120-4FA3-9867-34ACE562EF1B}",
				}, -- end of [8]
				[9] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [9]
				[10] = 
				{
					["CLSID"] = "{F72F47E5-C83A-4B85-96ED-D3E46671EE9A}",
				}, -- end of [10]
				[11] = 
				{
					["CLSID"] = "{FBC29BFE-3D24-4C64-B81D-941239D12249}",
				}, -- end of [11]
				[12] = 
				{
					["CLSID"] = "{44EE8698-89F9-48EE-AF36-5FD31896A82A}",
				}, -- end of [12]
			}, -- end of ["pylons"]
			["fuel"] = "9800",
			["flare"] = 64,
			["chaff"] = 64,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "af standard", "af standard 2" }, -- liveries for ["countries"][1]
		}
	}, -- end of [37]
} -- end of RTFighters
RTTransport = {
	[1] = {
		["type"] = "C-17A",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "132405",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "usaf standard" } -- liveries for ["countries"][1]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "C-130",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "45922",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.BELGIUM,
			[3] = country.id.DENMARK,
			[4] = country.id.FRANCE,
			[5] = country.id.UK,
			[6] = country.id.ISRAEL,
			[7] = country.id.CANADA,
			[8] = country.id.THE_NETHERLANDS,
			[9] = country.id.NORWAY,
			[10] = country.id.SPAIN,
			[11] = country.id.TURKEY
		},
		["liveries"] = { 
			[1] = { "US Air Force" }, -- liveries for ["countries"][1]
			[2] = { "Belgian Air Force" }, -- liveries for ["countries"][2]
			[3] = { "Royal Danish Air Force" }, -- liveries for ["countries"][3]
			[4] = { "French Air Force" }, -- liveries for ["countries"][4]
			[5] = { "Royal Air Force" }, -- liveries for ["countries"][5]
			[6] = { "Israel Defence Force" }, -- liveries for ["countries"][6]
			[7] = { "Canada's Air Force" }, -- liveries for ["countries"][7]
			[8] = { "Royal Netherlands Air Force" }, -- liveries for ["countries"][8]
			[9] = { "Royal Norwegian Air Force" }, -- liveries for ["countries"][9]
			[10] = { "Spanish Air Force" }, -- liveries for ["countries"][10]
			[11] = { "Turkish Air Force" } -- liveries for ["countries"][11]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "E-2D",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "12399",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "E-2D Demo", "VAW-125 Tigertails" } -- liveries for ["countries"][1]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "E-3A",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "143300",
			["flare"] = 60,
			["chaff"] = 120,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.FRANCE,
			[3] = country.id.UK
		},
		["liveries"] = { 
			[1] = { "nato", "usaf standard" }, -- liveries for ["countries"][1]
			[2] = { "nato" }, -- liveries for ["countries"][2]
			[3] = { "nato" }, -- liveries for ["countries"][3]
		}
	}, -- end of [4]
	[5] = {
		["type"] = "KC-135",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "199959",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "Standard USAF" } -- liveries for ["countries"][1]
		}
	}, -- end of [5]
	[6] = {
		["type"] = "MQ-1A Predator",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "441",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA
		},
		["liveries"] = { 
			[1] = { "USAF Standard" } -- liveries for ["countries"][1]
		}
	}, -- end of [6]
	[7] = {
		["type"] = "MQ-9 Reaper",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "2866",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,
			[2] = country.id.FRANCE,
			[3] = country.id.ITALY,
			[4] = country.id.UK
		},
		["liveries"] = { 
			[1] = { "'camo' scheme", "standard" }, -- liveries for ["countries"][1]
			[2] = { "standard France" }, -- liveries for ["countries"][2]
			[3] = { "standard Italy" }, -- liveries for ["countries"][3]
			[4] = { "standard UK" }, -- liveries for ["countries"][4]
		}
	}, -- end of [7]
	[8] = {
		["type"] = "S-3B Tanker",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "12125",
			["flare"] = 30,
			["chaff"] = 30,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.USA,			
		},
		["liveries"] = { 
			[1] = { "NAVY Standard" } -- liveries for ["countries"][1]
		}
	}, -- end of [8]
	[9] = {
		["type"] = "A-50",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "154324",
			["flare"] = 192,
			["chaff"] = 192,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,			
		},
		["liveries"] = { 
			[1] = { "RF Air Force", "RF Air Force New" } -- liveries for ["countries"][1]
		}
	}, -- end of [9]
	[10] = {
		["type"] = "An-26B",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "12125",
			["flare"] = 384,
			["chaff"] = 384,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2]	= country.id.ABKHAZIA,			
			[3] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "RF Air Force" }, -- liveries for ["countries"][1]
			[2] = { "Abkhazian AF" }, -- liveries for ["countries"][2]
			[3] = { "Ukraine AF" }, -- liveries for ["countries"][3]
		}
	}, -- end of [10]
	[11] = {
		["type"] = "An-26B",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "12125",
			["flare"] = 384,
			["chaff"] = 384,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.BLUE,
		["countries"] = { 
			[1] = country.id.GEORGIA
		},
		["liveries"] = { 
			[1] = { "Georgian AF" }, -- liveries for ["countries"][1]
		}
	}, -- end of [11]
	[12] = {
		["type"] = "An-30M",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "18298",
			["flare"] = 192,
			["chaff"] = 192,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,			
			[2] = country.id.UKRAINE
		},
		["liveries"] = { 
			[1] = { "RF Air Force" }, -- liveries for ["countries"][1]
			[2] = { "15th Transport AB" }, -- liveries for ["countries"][2]
		}
	}, -- end of [12]
	[13] = {
		["type"] = "IL-76MD",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "176370",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
			[2] = country.id.CHINA,
			[3] = country.id.UKRAINE,
		},
		["liveries"] = { 
			[1] = { "RF Air Force" }, -- liveries for ["countries"][1]
			[2] = { "China Air Force New", "China Air Force Old" }, -- liveries for ["countries"][2]
			[3] = { "Ukrainian AF", "Ukrainian AF aeroflot" }, -- liveries for ["countries"][3]
		}
	}, -- end of [13]
	[14] = {
		["type"] = "IL-78M",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "198416",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
		}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA,
		},
		["liveries"] = { 
			[1] = { "RF Air Force", "RF Air Force aeroflot", "RF Air Force new" }, -- liveries for ["countries"][1]
		}
	}, -- end of [14]
} -- end of RTTransport
RTCivilian = {
	[1] = {
		["type"] = "Yak-40",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "3080",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
			}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "Georgian Airlines", "Aeroflot", "Olympic Airways", "Ukranian" } -- liveries for ["countries"][1]
		}
	}, -- end of [1]
	[2] = {
		["type"] = "IL-76MD",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "176370",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
			}, -- end of ["payload"]
		["coalition"] = coalition.side.RED,
		["countries"] = { 
			[1] = country.id.RUSSIA
		},
		["liveries"] = { 
			[1] = { "FSB aeroflot" } -- liveries for ["countries"][1]
		}
	}, -- end of [2]
	[3] = {
		["type"] = "IL-76MD",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "176370",
			["flare"] = 96,
			["chaff"] = 96,
			["gun"] = 100,
			}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "MVD aeroflot" } -- liveries for ["countries"][1]
		}
	}, -- end of [3]
	[4] = {
		["type"] = "An-26B",
		["active"] = true,
		["payload"] = {
			["pylons"] =
			{
			}, -- end of ["pylons"]
			["fuel"] = "12125",
			["flare"] = 0,
			["chaff"] = 0,
			["gun"] = 100,
			}, -- end of ["payload"]
		["coalition"] = coalition.side.NEUTRAL,
		["countries"] = { 
			[1] = country.id.INSURGENTS
		},
		["liveries"] = { 
			[1] = { "Aeroflot" } -- liveries for ["countries"][1]
		}
	}, -- end of [4]
} -- end of RTCivilian

-- that's it for the configuration part, you are all set!
-- now go and create an awesome mission! :)
-- ...
-- don't go any further
-- this is not the code you are looking for *jedi gesture*

------------------------------------------------------------------------------
-- 								MAIN SCRIPT									--
------------------------------------------------------------------------------
-- if you change something below these lines and you screw up: 				--
-- don't ask me for help unless you show up at my door with a bottle of rum --
-- don't say i didn't warn you   											--
------------------------------------------------------------------------------

-- Rakus Training Spawns version
RTSVersion_Major = "0"
RTSVersion_Minor = "6"
RTSVersion = RTSVersion_Major .. "." .. RTSVersion_Minor

-- bool isempty(string s)
-- checks a string for null and empty
-- s: the string to checks
-- return: true if the string is either null or empty, otherwise false
local function isempty(s)
  return s == nil or s == ''
end

-- simple switch-case implementation
-- code from: http://lua-users.org/wiki/SwitchStatement
--[[usage: 
	switch(2):caseof{  
		[1] = function(x) return 111 end,
		[20] = function(x) return 20 end,
		default = function(x) return -1 end
		missing = function(x) return 0 end
	}
]]
function switch(c)
  local swtbl = {
    casevar = c,
    caseof = function (self, code)
      local f
      if (self.casevar) then
        f = code[self.casevar] or code.default
      else
        f = code.missing or code.default
      end
      if f then
        if type(f)=="function" then
          return f(self.casevar,self)
        else
          error("case "..tostring(self.casevar).." is not a function")
        end
      end
    end
  }
  return swtbl
end

-- void RTlog(string s, bool ingame)
-- logs a message
-- s: string to log
-- ingame: true if message should be displayed ingame, otherwise it will be written to log only
local function RTlog(s,ingame)
	if s then 
		env.info("RTS v" .. RTSVersion .. ": " .. s)
	else
		env.info("RTS v" .. RTSVersion .. ": nil")
	end
	
	if (ingame)
	then
		if s then
			trigger.action.outText(s, 10)
		else
			trigger.action.outText("nil",10)
		end
	end
end

-- bool tableContainsValue(table tbl, ? val)
-- returns true if the table tbl does contain val as one of its values
local function tableContainsValue(tbl,val)
	for i,v in ipairs(tbl)
	do
		if v == val
		then						
			return true
		end
	end
	
	return false
end

-- int getWeightedRandom(table weightTable)
-- calculates a weighted random number from a given array of weights
-- weightTable: the table containing the weights as its values, i.e. _weights = { 1, 5, 10, 3 }
-- return: the random index in the table
function getWeightedRandom(weightTable)
	local _weightSum = 0
	
	-- calculate sum of all weigths
	for i,w in ipairs(weightTable)
	do
		_weightSum = _weightSum + w
	end
	
	-- random number that is zero or greater and less the sum of the weights
	local _rndVal = math.random(0,_weightSum-1)
	
	-- iterate over each item
	-- subtract itemweight from randomnumber until randomnumber is less than the weight
	for i,w in ipairs(weightTable)
	do
		if (_rndVal < w)
		then
			return i
		end
		_rndVal = _rndVal - w
	end
end

-- void destroyGroup(string groupId)
-- destroys a group... you guessed it right
function destroyGroup(groupId)
	local _group = Group.getByName(groupId)
	if _group
	then
		_group:destroy()
	end
end

-- table tableConcat(table tbl1, table tbl2)
-- concatenates two tables without modifying the original tables
-- return: the new table
local function tableConcat(tbl1,tbl2)
	local tbl = {}
	for i=1,#tbl1
	do
		tbl[#tbl+1] = tbl1[i]
	end
	for i=1,#tbl2
	do
		tbl[#tbl+1] = tbl2[i]
	end
	return tbl
end

-- void buildRTSTable()
-- builds the RTS table
-- sets up difficulties, aircraft and countries
RTS = {}
RTS.Groups = {}
local function buildRTSTable()
	
	RTS.BoardNumberCounter = 10
	
	RTS.Easy = {
		Aircraft = {},
		FlightSize = RTSConf_FixedWing_Easy_FlightSize,
		Altitude = RTSConf_FixedWing_Easy_Altitude,
		AltType = RTSConf_FixedWing_Easy_AltType,
		Active = false,
		Count = 0,
		DifficultyString = RTSConf_StringEasy
	}
	RTS.Medium = {
		Aircraft = {},
		FlightSize = RTSConf_FixedWing_Medium_FlightSize,
		Altitude = RTSConf_FixedWing_Medium_Altitude,
		AltType = RTSConf_FixedWing_Medium_AltType,
		Active = false,
		Count = 0,
		DifficultyString = RTSConf_StringMedium
	}
	RTS.Hard = {
		Aircraft = {},
		FlightSize = RTSConf_FixedWing_Hard_FlightSize,
		Altitude = RTSConf_FixedWing_Hard_Altitude,
		AltType = RTSConf_FixedWing_Hard_AltType,
		Active = false,
		Count = 0,
		DifficultyString = RTSConf_StringHard
	}
	RTS.Heavy = {
		Aircraft = {},
		FlightSize = 1,
		Altitude = RTSConf_FixedWing_Heavy_Altitude,
		AltType = RTSConf_FixedWing_Heavy_AltType,
		Active = false,
		Count = 0,
		DifficultyString = RTSConf_StringHeavy
	}
	
	local _fixedWing = tableConcat(RTBombers, RTFighters)
	_fixedWing = tableConcat(_fixedWing, RTTransport)
	_fixedWing = tableConcat(_fixedWing, RTCivilian)
	
	local _helis = tableConcat(RTHelicoptersAttack, RTHelicoptersCivilian)
	_helis = tableConcat(_helis, RTHelicoptersTransport)
	
	for i=#_fixedWing,1,-1
	do
		repeat
			local _craft = _fixedWing[i]
			
			if tableContainsValue(RTSConf_FixedWing_Easy, _craft["type"])
			then
				RTS.Easy.Aircraft[#RTS.Easy.Aircraft+1] = _craft
				break
			end
			
			if tableContainsValue(RTSConf_FixedWing_Medium, _craft["type"])
			then
				RTS.Medium.Aircraft[#RTS.Medium.Aircraft+1] = _craft
				break
			end
			
			if tableContainsValue(RTSConf_FixedWing_Hard, _craft["type"])
			then
				RTS.Hard.Aircraft[#RTS.Hard.Aircraft+1] = _craft
				break
			end
			
			if tableContainsValue(RTSConf_FixedWing_Heavy, _craft["type"])
			then
				RTS.Heavy.Aircraft[#RTS.Heavy.Aircraft+1] = _craft
				break
			end
		until true
	end
	
	RTS.Countries = {}
	RTS.Countries.RED = {}
	RTS.Countries.BLUE = {}
	
	for name,index in pairs(country.id)
	do
		if coalition.getCountryCoalition(index) == coalition.side.RED
		then
			RTS.Countries.RED[#RTS.Countries.RED+1] = index
		end
		
		if coalition.getCountryCoalition(index) == coalition.side.BLUE		
		then
			RTS.Countries.BLUE[#RTS.Countries.BLUE+1] = index
		end
	end
end

-- void spawnAircraft(table difficulty, number coal, table spawnZones, string flyToZone)
-- main fucntion.
-- do i have to say more?
RTS.spawnAircraft = function(difficulty, coal, spawnZones, flyToZone)
	
	-- 0. sanity checks
	assert(difficulty and (difficulty == RTS.Easy or difficulty == RTS.Medium or difficulty == RTS.Hard or difficulty == RTS.Heavy),'unknown difficulty given!')
	assert(coal and (coal == coalition.side.BLUE or coal == coalition.side.RED), 'coalition is neither blue nor red!')
	assert(spawnZones and #spawnZones > 0, 'no spawnzones given!')
	assert(flyToZone and type(flyToZone) == 'string','no fly to zone given!')
	
	-- 00. check if another group is still active
	if RTSConf_OneGroupPerDifficulty
	then
		if difficulty.Active
		then
			if RTSConf_MessageGroupActive
			then
				trigger.action.outText(RTSConf_StringGroupActive,10)
			end
			
			return
		else
			difficulty.Active = true
		end
	end
	
	-- 1. variable definitions
	local _craft = nil
	local _country = nil
	local _cindex = -1
	local _liveryId = -1
	local _groupId = nil
	local _waypoints = {}
	local _payload = {}
	local _spawnPos = {}
	local _destPos = {}
	local _data = {}
	local _altitude = switch(type(difficulty.Altitude)):caseof{
		['number'] = function(x) return difficulty.Altitude end,
		['table'] = function(x) if #difficulty.Altitude == 2 then return math.random(difficulty.Altitude[1], difficulty.Altitude[2]) else return 6000 end end,
		default = function(x) return 6000 end
	}
	
	-- 2. get a craft, country, livery and group id
	_craft = difficulty.Aircraft[math.random(#difficulty.Aircraft)]
	_cIndex = math.random(#_craft["countries"])
	_country = _craft["countries"][_cIndex]
	_liveryId = _craft["liveries"][_cIndex][math.random(#_craft["liveries"][_cIndex])]
	_groupId = RTSConf_GroupPrefix .. math.random(1,999999999)
	
	-- 3. get spawn position and destination position
	_spawnPos = mist.getRandomPointInZone(spawnZones[math.random(#spawnZones)])
	_destPos = mist.getRandomPointInZone(flyToZone)	
	
	-- 4. create first waypoint	
	_waypoints[#_waypoints+1] = {
		["alt"] = _altitude,
		["type"] = "Turning Point",
		["action"] = "Turning Point",
		["alt_type"] = difficulty.AltType,
		["formation_template"] = "",
		["properties"] = 
		{
			["vnav"] = 1,
			["scale"] = 0,
			["angle"] = 0,
			["vangle"] = 0,
			["steer"] = 2,
		}, -- end of ["properties"]
		["ETA"] = 0,
		["ETA_locked"] = true,
		["y"] = _spawnPos.y,
		["x"] = _spawnPos.x,
		["speed"] = 250,
		["speed_locked"] = true,
		["task"] = 
		{
			["id"] = "ComboTask",
			["params"] = 
			{
				["tasks"] = 
				{
					[1] = 
					{
						["enabled"] = true,
						["auto"] = false,
						["id"] = "Orbit",
						["number"] = 1,
						["params"] = 
						{
							["altitude"] = _altitude,
							["pattern"] = "Race-Track",
							["speed"] = 250,
						}, -- end of ["params"]
					}, -- end of [1]
				}, -- end of ["tasks"]
			}, -- end of ["params"]
		}, -- end of ["task"]
	}
	
	-- 5. create second waypoint
	_waypoints[#_waypoints+1] = {
		["alt"] = _altitude,
		["type"] = "Turning Point",
		["action"] = "Turning Point",
		["alt_type"] = difficulty.AltType,
		["formation_template"] = "",
		["properties"] = 
		{
			["vnav"] = 1,
			["scale"] = 0,
			["angle"] = 0,
			["vangle"] = 0,
			["steer"] = 2,
		}, -- end of ["properties"]
		["ETA"] = 0,
		["ETA_locked"] = false,
		["y"] = _destPos.y,
		["x"] = _destPos.x,
		["speed"] = 250,
		["speed_locked"] = true,
		["task"] =  {
			["id"] = "ComboTask",
			["params"] = {
				["tasks"] = {							   
				}, -- end of ["tasks"]
			}, -- end of ["params"]
		}, -- end of ["task"]
	}
	
	-- 6. dearm if neccessary
	if difficulty == RTS.Medium or difficulty == RTS.Easy
	then
		_craft["payload"]["pylons"] = {}
	end
	
	if difficulty == RTS.Easy
	then
		_craft["payload"]["gun"] = 0
		_craft["payload"]["chaff"] = 0
		_craft["payload"]["flare"] = 0
	end
	
	-- 7. set up units according to flight size
	local _hdg = 360 - ((((math.atan2((_waypoints[2].y - _waypoints[1].y),(_waypoints[2].x - _waypoints[1].x))) * (180 / math.pi)) + 360) % 360)
	local _units = {}
	local _coordX = _waypoints[1].x
	local _coordY = _waypoints[1].y
	
	for i=1,difficulty.FlightSize,1
	do
		_units[#_units+1] = {
			["alt"] = _waypoints[1].alt,
			["heading"] = _hdg,
			["livery_id"] = _liveryId,
			["type"] = _craft["type"],
			["psi"] = 0,
			["onboard_num"] = RTS.BoardNumberCounter,
			["y"] = _coordY,
			["x"] = _coordX,
			["name"] =  _groupId .. "" .. i,
			["payload"] = _craft["payload"],
			["speed"] = _waypoints[1].speed,
			["unitId"] =  math.random(9999,99999),
			["alt_type"] = _waypoints[1].alt_type,
			["skill"] = "Excellent",
		}
		
		_coordX = _coordX + 50
		_coordY = _coordY + 50
		RTS.BoardNumberCounter = RTS.BoardNumberCounter + 1
	end
	
	-- 8. set up final data
	_data = {
		["modulation"] = 0,
		["tasks"] = {},
		["task"] = "CAS",
		["uncontrolled"] = false,
		["route"] = {
			["points"] = _waypoints
		}, -- end of ["route"]
		["groupId"] = _groupId,
		["hidden"] = false,
		["units"] = _units,
		["y"] = _waypoints[1].y,
		["x"] = _waypoints[1].x,
		["name"] =  _groupId,
		["communication"] = true,
		["start_time"] = 0,
		["frequency"] = 124
	} -- end of _data
	
	-- spawn me in, scotty!
	local _category = Group.Category.AIRPLANE
	
	if(coal == coalition.side.RED)
	then
		coalition.addGroup(RTS.Countries.RED[math.random(#RTS.Countries.RED)], _category, _data)
	elseif (coal == coalition.side.BLUE)
	then
		coalition.addGroup(RTS.Countries.BLUE[math.random(#RTS.Countries.BLUE)], _category, _data)
	end
	
	RTlog("Group spawned: " .. _craft["type"] .. " - Group ID: " .. _groupId)
	
	if difficulty == RTS.Easy
	then
		local _groupController = Group.getByName(_groupId):getController()
		_groupController:setOption(AI.Option.Air.id.PROHIBIT_AA, true)
		_groupController:setOption(AI.Option.Air.id.REACTION_ON_THREAT, AI.Option.Air.val.REACTION_ON_THREAT.NO_REACTION)
		RTlog("Group " .. _groupId .. " set to not attack anything")
	end
	
	difficulty.Count = difficulty.Count + 1
	
	_rtsUnits = {}
	for i,v in ipairs(_units) do
		_rtsUnits[#_rtsUnits+1] = { name = v["name"], dead = false }
	end
	
	RTS.Groups[#RTS.Groups+1] = {
		id = _groupId,
		dif = difficulty.DifficultyString,
		units = _rtsUnits,
		spawnTime = timer.getTime(),
		count = difficulty.Count,
	}
	
	if(RTSConf_MessageGroupSpawned)
	then
		local _msg = RTSConf_StringGroupSpawned:gsub("$Difficulty", RTS.Groups[#RTS.Groups].dif)
		_msg = _msg:gsub("$Count", RTS.Groups[#RTS.Groups].count)
		trigger.action.outText(_msg, 10)
	end
end -- end function spawnAircraft()

RTSUnitDeadHandler = {}
function RTSUnitDeadHandler:onEvent(event)
	if(world.event.S_EVENT_DEAD == event.id or world.event.S_EVENT_PILOT_DEAD == event.id or world.event.S_EVENT_EJECTION == event.id or world.event.S_EVENT_CRASH == event.id)
	then
		local _unitName = event.initiator:getName()
		for i=#RTS.Groups,1,-1
		do
			local _group = RTS.Groups[i]
			local _found = false
			
			for i,_unit in ipairs(_group.units)
			do
				if (_unit.name == _unitName and not _unit.dead)
				then
					_unit.dead = true
					_found = true
					break
				end
			end
			
			if found
			then
				break
			end
		end
	end
end

local function checkDeadGroups()
	for i=#RTS.Groups,1,-1
	do
		repeat
			local _group = RTS.Groups[i]
			
			local _groupDead = true
			
			for i,unit in ipairs(_group.units)
			do
				_groupDead = _groupDead and unit.dead
			end
			
			if (_groupDead or not Group.getByName(_group.id))
			then
				
				if RTSConf_OneGroupPerDifficulty
				then
					switch(_group.dif):caseof{
						[RTSConf_StringEasy] = function(x) RTS.Easy.Active = false end,
						[RTSConf_StringMedium] = function(x) RTS.Medium.Active = false end,
						[RTSConf_StringHard] = function(x) RTS.Hard.Active = false end,
						[RTSConf_StringHeavy] = function(x) RTS.Heavy.Active = false end,
					}
				end
				
				if RTSConf_MessageGroupDead
				then
					local _msg = RTSConf_StringGroupDead:gsub("$Difficulty", _group.dif)
					_msg = _msg:gsub("$Count", _group.count)
					trigger.action.outText(_msg, 10)
				end
				RTlog("Removing group " .. _group.id .. ": dead")
				table.remove(RTS.Groups,i)
				break
			end
			
			if(_group.spawnTime + RTSConf_GroupTimeout < timer.getTime())
			then
				if RTSConf_OneGroupPerDifficulty
				then
					switch(_group.dif):caseof{
						[RTSConf_StringEasy] = function(x) RTS.Easy.Active = false end,
						[RTSConf_StringMedium] = function(x) RTS.Medium.Active = false end,
						[RTSConf_StringHard] = function(x) RTS.Hard.Active = false end,
						[RTSConf_StringHeavy] = function(x) RTS.Heavy.Active = false end,
					}
				end
				
				if RTSConf_MessageGroupTimeout
				then
					local _msg = RTSConf_StringGroupRemoved:gsub("$Difficulty", _group.dif)
					_msg = _msg:gsub("$Count", _group.count)
					trigger.action.outText(_msg, 10)
				end
				RTlog("Removing group " .. _group.id .. ": timeout")
				destroyGroup(_group.id)		
				table.remove(RTS.Groups,i)
				break
			end
		until true
	end
end

buildRTSTable()
world.addEventHandler(RTSUnitDeadHandler)
mist.scheduleFunction(checkDeadGroups, {}, timer.getTime() + 1, 1)

RTlog("Rakus Training Spawns loaded")

end --end main do